# MLIL Python Client
This package allows you to more easily interact with the MLIL paltform via Python

## Basic usage:

    >>> import mlil
    >>> client = mlil.MLIL_client()
    >>> client.actions

